@@ -5,38 +5,44 @@ import pytest
 from nameko.parallel import (
     ParallelExecutor, parallel_provider, ParallelProvider,
     ParallelProxyFactory, ProxySettingUnsupportedException)
-from nameko.containers import (
-    ManagedThreadContainer, ServiceContainer, WorkerContext)
+from nameko.containers import ServiceContainer, WorkerContext
 from nameko.runners import ServiceRunner
 from nameko.testing.utils import wait_for_call
 from nameko.timer import timer
 
 
-def test_parallel_executor_submit_makes_call():
+@pytest.fixture()
+def container():
+    class Service(object):
+        pass
+    return ServiceContainer(Service, None, {})
+
+
+def test_parallel_executor_submit_makes_call(container):
     to_call = Mock(return_value=99)
-    future = ParallelExecutor(ManagedThreadContainer()).submit(to_call, 1)
+    future = ParallelExecutor(container).submit(to_call, 1)
     with wait_for_call(5, to_call) as to_call_waited:
         to_call_waited.assert_called_with(1)
         assert future.result() == 99
 
 
-def test_calling_result_waits():
+def test_calling_result_waits(container):
     to_call = Mock(return_value=99)
-    future = ParallelExecutor(ManagedThreadContainer()).submit(to_call, 1)
+    future = ParallelExecutor(container).submit(to_call, 1)
     assert future.result() == 99
     to_call.assert_called_with(1)
 
 
-def test_parallel_executor_context_manager():
+def test_parallel_executor_context_manager(container):
     to_call = Mock()
-    with ParallelExecutor(ManagedThreadContainer()) as execution_context:
+    with ParallelExecutor(container) as execution_context:
         execution_context.submit(to_call, 4)
     # No waiting, the context manager handles that
     to_call.assert_called_with(4)
 
 
-def test_no_submit_after_shutdown():
-    pe = ParallelExecutor(ManagedThreadContainer())
+def test_no_submit_after_shutdown(container):
+    pe = ParallelExecutor(container)
     to_call = Mock()
     with pe as execution_context:
         execution_context.submit(to_call, 1)
@@ -44,8 +50,8 @@ def test_no_submit_after_shutdown():
         pe.submit(to_call, 2)
 
 
-def test_future_gets_exception():
-    pe = ParallelExecutor(ManagedThreadContainer())
+def test_future_gets_exception(container):
+    pe = ParallelExecutor(container)
 
     def raises():
         raise AssertionError()
@@ -56,16 +62,16 @@ def test_future_gets_exception():
         future.result()
 
 
-def test_stop_managed_container():
-    container = ManagedThreadContainer()
+def test_stop_managed_container(container):
+    container = container
     pe = ParallelExecutor(container)
     with pe as execution_context:
         execution_context.submit(everlasting_call)
         container.stop()
 
 
-def test_kill_managed_container():
-    container = ManagedThreadContainer()
+def test_kill_managed_container(container):
+    container = container
     pe = ParallelExecutor(container)
     with pe as execution_context:
         f = execution_context.submit(everlasting_call)
@@ -74,12 +80,12 @@ def test_kill_managed_container():
             f.result()
 
 
-def test_parallel_proxy_context_manager():
+def test_parallel_proxy_context_manager(container):
     to_wrap = Mock()
     to_wrap.wrapped_attribute = 2
     to_call = Mock()
     to_wrap.wrapped_call = to_call
-    with ParallelProxyFactory(ManagedThreadContainer())(to_wrap) as wrapped:
+    with ParallelProxyFactory(container)(to_wrap) as wrapped:
         # Non-callables are returned immediately
         assert wrapped.wrapped_attribute == 2
 
@@ -88,13 +94,13 @@ def test_parallel_proxy_context_manager():
     to_call.assert_called_with(5)
 
 
-def test_proxy_read_only():
+def test_proxy_read_only(container):
     class Dummy(object):
         pass
 
     dummy = Dummy()
 
-    with ParallelProxyFactory(ManagedThreadContainer())(dummy) as wrapped:
+    with ParallelProxyFactory(container)(dummy) as wrapped:
         # Setting attributes is not allowed
         with pytest.raises(ProxySettingUnsupportedException):
             wrapped.set_me = 1
